# pylss

Python implementation of `ls` command

## **`ls is a command to list computer files in Unix and Unix-like operating systems.`**

## Usage

_`pip install pylss`_

- in terminal
  ```py
  python -u pylss
  ```
- importing as a function
  ```py
  import getDirList from pylss
  ```
